@@ -35,7 +35,7 @@ from metview import plotting
 from metview.metviewpy.ipython import is_ipython_active, import_widgets
 from metview.metviewpy import utils
 
-__version__ = "1.12.0"
+__version__ = "1.13.0"
 
 
 # logging.basicConfig(level=logging.DEBUG, format="%(levelname)s - %(message)s")
@@ -737,6 +737,41 @@ class Fieldset(FileBackedValueWithOperators, ContainerValue):
     def sort(self, *args, **kwargs):
         return self._get_db().sort(*args, **kwargs)
 
+    def apply_function_over_dim(self, dim, preserve_dims, func_to_run, name, **kwargs):
+        if len(self) == 0:
+            raise ValueError(f"Input to function {name} is an empty Fieldset")
+
+        if dim is None:
+            return func_to_run(self, **kwargs)
+
+        import itertools
+
+        if preserve_dims:
+            _preserve_dims = preserve_dims
+        else:
+            _preserve_dims = ["shortName", "level", "step", "number", "date", "time"]
+        if dim in _preserve_dims:
+            _preserve_dims.remove(dim)
+        dim_combos = {k: unique(self.grib_get_string(k)) for k in _preserve_dims}
+        keys, values = zip(*dim_combos.items())
+        perms = [dict(zip(keys, v)) for v in itertools.product(*values)]
+        # e.g. [{level=1000,shortName="t",date=20220101, time=6}, ...]
+        fieldsets_to_apply_function_to = [self.select(**x) for x in perms]
+        result = Fieldset(
+            fields=[func_to_run(x, **kwargs) for x in fieldsets_to_apply_function_to]
+        )
+        return result
+
+    def mean(self, dim=None, preserve_dims=None, missing=False):
+        return self.apply_function_over_dim(
+            dim, preserve_dims, met_mean, "mean", missing=missing
+        )
+
+    def sum(self, dim=None, preserve_dims=None, missing=False):
+        return self.apply_function_over_dim(
+            dim, preserve_dims, met_sum, "sum", missing=missing
+        )
+
     @property
     def ds_param_info(self):
         if self._ds_param_info is None:
@@ -797,6 +832,15 @@ class Fieldset(FileBackedValueWithOperators, ContainerValue):
         r._init_db_from(self)
         return r
 
+    def convolve(self, *args, **kwargs):
+        return utils.convolve(self, *args, **kwargs)
+
+    def smooth_n_point(self, *args, **kwargs):
+        return utils.smooth_n_point(self, *args, **kwargs)
+
+    def smooth_gaussian(self, *args, **kwargs):
+        return utils.smooth_gaussian(self, *args, **kwargs)
+
     def _init_db_from(self, other):
         if self._db is None and other._db is not None:
             self._db = FieldsetDb(self, other.label)
@@ -1284,7 +1328,16 @@ def bind_functions(namespace, module_name=None):
         namespace.pop(name)
 
     # add some object methods the to global namespace
-    for name in ["to_dataset", "to_dataframe", "ls", "describe", "select"]:
+    for name in [
+        "to_dataset",
+        "to_dataframe",
+        "ls",
+        "describe",
+        "select",
+        "convolve",
+        "smooth_n_point",
+        "smooth_gaussian",
+    ]:
         namespace[name] = _make_function_for_object(name)
 
 
@@ -1302,6 +1355,7 @@ greater_than = make(">")
 _keywords = make("keywords")
 lower_equal_than = make("<=")
 lower_than = make("<")
+met_mean = make("mean")
 met_merge = make("&")
 met_not_eq = make("<>")
 met_plot = make("plot")
@@ -1316,11 +1370,13 @@ met_setoutput = make("setoutput")
 metzoom = make("metzoom")
 sub = make("-")
 subset = make("[]")
+met_sum = make("sum")
 met_and = make("and")
 met_or = make("or")
 met_not = make("not")
 met_version_info = make("version_info")
 _request = make("request")
+unique = make("unique")
 write = make("write")
 
 
